<?php

require('./config.php');
require('./libs/Pardakhtyar.php');
require('./libs/functions.php');

$errors = array();


if(strtolower($_SERVER['REQUEST_METHOD']) == 'post' && isset($_POST['paymentNumber'])){
    if(isset($_POST['status']) && $_POST['status'] == 1){
        $pardakhtyar = new Pardakhtyar();
        $params = array(
            'apiKey' => API_KEY,
            'paymentNumber' => $_POST['paymentNumber'],
        );
        $request = $pardakhtyar->paymentVerify($params);
        if($request['status']){
            $message = 'پرداخت شما با موفقیت انجام شد <br /> شماره پرداخت : '.$_POST['paymentNumber'];
        }else{
            $errors[] = $request['message'];
        }
    }else{

        $errors[] = 'متاسفانه پرداخت انجام نشد';

    }
}

if(isset($_POST['submit'])){

    $_POST = clean($_POST);

    if(empty(trim($_POST['payer_name']))){
        $errors[] = 'نام و نام خانوادگی خود را وارد کنید';
    }

    if(empty(trim($_POST['payer_email']))){
        $errors[] = 'پست الکترونیکی خود را وارد کنید';
    }elseif(!filter_var($_POST['payer_email'], FILTER_VALIDATE_EMAIL)){
        $errors[] = 'پست الکترونیکی وارد شده معتبر نیست';
    }

    if(empty(trim($_POST['payer_mobile']))){
        $errors[] = 'شماره موبایل خود را وارد کنید';
    }elseif(!preg_match('/^09[0-9]{9}$/i', $_POST['payer_mobile'])){
        $errors[] = 'شماره موبایل وارد شده معتبر نیست';
    }

    if(empty(trim($_POST['amount']))){
        $errors[] = 'مبلغ را وارد کنید';
    }elseif(!is_numeric($_POST['amount'])){
        $errors[] = 'مبلغ وارد شده معتبر نیست';
    }elseif($_POST['amount'] < 1000){
        $errors[] ='مبلغ نمی تواند کمتر از 1000 ریال باشد';
    }


    if(empty($errors)){
        $pardakhtyar = new Pardakhtyar();

        $params = array(
            'apiKey' => API_KEY,
            'amount' => $_POST['amount'],
            'callbackUrl' => SCRIPT_URL,
            'invoiceNumber' => time(),
            'payerName' => $_POST['payer_name'],
            'payerEmail' => $_POST['payer_email'],
            'payerMobile' => $_POST['payer_mobile'],
            'description' => $_POST['description'],
        );
        $request = $pardakhtyar->paymentRequest($params);

        if($request['status']){
            $pardakhtyar->paymentGateway($request['paymentNumber']);
        }else{
            $errors[] = $request['message'];
        }
    }
}

?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>
        <?php echo SITE_TITLE; ?>
    </title>
    <link rel="stylesheet" href="assets/css/bootstrap.min.css" />
    <link rel="stylesheet" href="assets/css/bootstrap-rtl.min.css" />
    <link rel="stylesheet" href="assets/css/styles.css">

</head>
<body>


    <nav class="navbar navbar-default">
        <div class="container">
            <!-- Brand and toggle get grouped for better mobile display -->
            <div class="navbar-header">
                <button type="button" class="navbar-toggle collapsed" data-toggle="collapse" data-target="#bs-example-navbar-collapse-1" aria-expanded="false">
                    <span class="sr-only">منو</span>
                    <span class="icon-bar"></span>
                    <span class="icon-bar"></span>
                    <span class="icon-bar"></span>
                </button>
                <a class="navbar-brand" href="">
                    <?php echo SITE_TITLE; ?> - پرداخت آنلاین
                </a>
            </div>
        </div><!-- /.container-fluid -->
    </nav>


    <div id="main">
        <div class="container">
            <div class="row">

                <div class="col-sm-6 col-sm-offset-3">

                    <?php if(isset($errors) && count($errors)) : ?>
                        <div class="alert alert-danger">
                            <ul>
                            <?php foreach($errors as $error) : ?>
                                <li><?php echo $error; ?></li>
                            <?php endforeach; ?>
                            </ul>
                        </div>
                    <?php endif; ?>

                    <?php if(isset($message)) :  ?>
                    <div class="alert alert-success">
                        <?php echo $message; ?>
                    </div>
                    <?php endif; ?>

                    <form method="post" action="">
                        <div class="form-group">
                            <label class="control-label">نام و نام خانوادگی</label>
                            <input name="payer_name" class="form-control" value="<?php echo post('payer_name'); ?>" />
                        </div>
                        <div class="form-group">
                            <label class="control-label">پست الکترونیکی</label>
                            <input name="payer_email" class="form-control" type="email" value="<?php echo post('payer_email'); ?>" />
                        </div>
                        <div class="form-group">
                            <label class="control-label">شماره موبایل</label>
                            <input name="payer_mobile" class="form-control" type="tel" value="<?php echo post('payer_mobile'); ?>" />
                        </div>
                        <div class="form-group">
                            <label class="control-label">مبلغ (ریال)</label>
                            <input name="amount" class="form-control" type="number" value="<?php echo post('amount'); ?>" />
                        </div>
                        <div class="form-group">
                            <label class="control-label">توضیحات</label>
                            <textarea name="description" class="form-control" rows="5" ><?php echo post('description'); ?></textarea>
                        </div>
                        <div class="form-group" >
                            <button type="submit" name="submit" class="btn btn-primary">
                                پرداخت آنلاین
                            </button>
                        </div>
                    </form>


                </div>

            </div>
        </div>
    </div>


</body>
</html>